Class: OpenEHR::RM::Composition::Content::Entry::IsmTransition
- Inherits:
-
OpenEHR::RM::Common::Archetyped::Pathable
- Object
- OpenEHR::RM::Common::Archetyped::Pathable
- OpenEHR::RM::Composition::Content::Entry::IsmTransition
- Defined in:
- lib/openehr/rm/composition/content/entry.rb
Instance Attribute Summary collapse
-
#careflow_step ⇒ Object
Returns the value of attribute careflow_step.
-
#current_state ⇒ Object
Returns the value of attribute current_state.
-
#reason ⇒ Object
RM 1.1.0: optional list of one or more reasons for this careflow step having been taken (e.g. useful in medication management, where several reasons may apply).
-
#transition ⇒ Object
Returns the value of attribute transition.
Attributes inherited from OpenEHR::RM::Common::Archetyped::Pathable
Instance Method Summary collapse
-
#initialize(args = { }) ⇒ IsmTransition
constructor
A new instance of IsmTransition.
Methods inherited from OpenEHR::RM::Common::Archetyped::Pathable
#item_at_path, #items_at_path, normalize_path, path_attribute, path_attributes, #path_children, #path_exists?, #path_of_item, #path_unique?, select_by_predicate
Constructor Details
#initialize(args = { }) ⇒ IsmTransition
Returns a new instance of IsmTransition.
243 244 245 246 247 248 249 |
# File 'lib/openehr/rm/composition/content/entry.rb', line 243 def initialize(args = { }) super(args) self.current_state = args[:current_state] self.transition = args[:transition] self.careflow_step = args[:careflow_step] self.reason = args[:reason] end |
Instance Attribute Details
#careflow_step ⇒ Object
Returns the value of attribute careflow_step.
237 238 239 |
# File 'lib/openehr/rm/composition/content/entry.rb', line 237 def careflow_step @careflow_step end |
#current_state ⇒ Object
Returns the value of attribute current_state.
236 237 238 |
# File 'lib/openehr/rm/composition/content/entry.rb', line 236 def current_state @current_state end |
#reason ⇒ Object
RM 1.1.0: optional list of one or more reasons for this careflow step having been taken (e.g. useful in medication management, where several reasons may apply).
241 242 243 |
# File 'lib/openehr/rm/composition/content/entry.rb', line 241 def reason @reason end |
#transition ⇒ Object
Returns the value of attribute transition.
236 237 238 |
# File 'lib/openehr/rm/composition/content/entry.rb', line 236 def transition @transition end |