Class: OpenEHR::RM::DataTypes::Text::CodePhrase
- Inherits:
-
Object
- Object
- OpenEHR::RM::DataTypes::Text::CodePhrase
- Defined in:
- lib/openehr/rm/data_types/text.rb
Instance Attribute Summary collapse
-
#code_string ⇒ Object
Returns the value of attribute code_string.
-
#preferred_term ⇒ Object
RM 1.1.0: optional preferred term for code_string, typically used in integration mappings that need both a (non-preferred) actual term and a preferred term.
-
#terminology_id ⇒ Object
Returns the value of attribute terminology_id.
Instance Method Summary collapse
-
#initialize(args = {}) ⇒ CodePhrase
constructor
A new instance of CodePhrase.
Constructor Details
#initialize(args = {}) ⇒ CodePhrase
Returns a new instance of CodePhrase.
67 68 69 70 71 |
# File 'lib/openehr/rm/data_types/text.rb', line 67 def initialize(args = {}) self.code_string = args[:code_string] self.terminology_id = args[:terminology_id] self.preferred_term = args[:preferred_term] end |
Instance Attribute Details
#code_string ⇒ Object
Returns the value of attribute code_string.
61 62 63 |
# File 'lib/openehr/rm/data_types/text.rb', line 61 def code_string @code_string end |
#preferred_term ⇒ Object
RM 1.1.0: optional preferred term for code_string, typically used in integration mappings that need both a (non-preferred) actual term and a preferred term.
65 66 67 |
# File 'lib/openehr/rm/data_types/text.rb', line 65 def preferred_term @preferred_term end |
#terminology_id ⇒ Object
Returns the value of attribute terminology_id.
61 62 63 |
# File 'lib/openehr/rm/data_types/text.rb', line 61 def terminology_id @terminology_id end |