Class: OpenEHR::AQL::Model::IdentifiedPath
- Inherits:
-
Object
- Object
- OpenEHR::AQL::Model::IdentifiedPath
- Defined in:
- lib/openehr/aql/model/identified_path.rb
Overview
identifiedPath : IDENTIFIER pathPredicate? (SYM_SLASH objectPath)? ; A variable reference, optionally constrained by a predicate on the variable itself (e.g. "c[at001 or at002]"), optionally followed by an object path rooted at that variable (e.g. "o/data/.../value").
Instance Attribute Summary collapse
-
#path ⇒ Object
readonly
Returns the value of attribute path.
-
#predicate ⇒ Object
readonly
Returns the value of attribute predicate.
-
#variable ⇒ Object
readonly
Returns the value of attribute variable.
Instance Method Summary collapse
-
#initialize(variable:, predicate: nil, path: nil) ⇒ IdentifiedPath
constructor
A new instance of IdentifiedPath.
Constructor Details
#initialize(variable:, predicate: nil, path: nil) ⇒ IdentifiedPath
Returns a new instance of IdentifiedPath.
11 12 13 14 15 16 |
# File 'lib/openehr/aql/model/identified_path.rb', line 11 def initialize(variable:, predicate: nil, path: nil) @variable = variable @predicate = predicate @path = path freeze end |
Instance Attribute Details
#path ⇒ Object (readonly)
Returns the value of attribute path.
9 10 11 |
# File 'lib/openehr/aql/model/identified_path.rb', line 9 def path @path end |
#predicate ⇒ Object (readonly)
Returns the value of attribute predicate.
9 10 11 |
# File 'lib/openehr/aql/model/identified_path.rb', line 9 def predicate @predicate end |
#variable ⇒ Object (readonly)
Returns the value of attribute variable.
9 10 11 |
# File 'lib/openehr/aql/model/identified_path.rb', line 9 def variable @variable end |